import React, { ReactNode } from 'react';
import { getTranslations } from 'next-intl/server';
import { Header, Footer } from '../../../components/Page';

export async function generateMetadata({
    params: { locale }
}: { params: { locale: string }}) {
    const t = await getTranslations({ locale, namespace: 'Main' });

    return {
        title: t('title'),
        description: t('description'),
    };
}

export default function MainLayout({ children, news, directions, experts, params: { locale } }: {
    children: ReactNode,
    news: ReactNode,
    directions: ReactNode,
    experts: ReactNode,
    params: { locale: string }
}) {
    return (
        <div className="b-wrapper">
            <div className="b-content">
                <Header locale={locale} />
                {children}
                {news}
                {directions}
                {experts}
            </div>
            <Footer />
        </div>
    );
};
